@@ -1,19 +1,19 @@
-// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2010 David Sugar, Tycho Softworks.
 //
-// This file is part of GNU ucommon.
+// This file is part of GNU uCommon C++.
 //
-// GNU ucommon is free software: you can redistribute it and/or modify
+// GNU uCommon C++ is free software: you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published 
 // by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// GNU ucommon is distributed in the hope that it will be useful,
+// GNU uCommon C++ is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with GNU ucommon.  If not, see <http://www.gnu.org/licenses/>.
+// along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <config.h>
 #include <ucommon/socket.h>
@@ -1840,6 +1840,19 @@ int Socket::broadcast(socket_t so, bool enable)
               (char *)&opt, (socklen_t)sizeof(opt));
 }
 
+int Socket::nodelay(socket_t so)
+{
+	if(so == INVALID_SOCKET)
+		return -1;
+#if defined(TCP_NODELAY)
+	int opt = 1;
+	return ::setsockopt(so, IPPROTO_TCP, TCP_NODELAY,
+		(char *)&opt, (socklen_t)sizeof(opt));
+#else
+	return -1;
+#endif
+}
+
 int Socket::keepalive(socket_t so, bool enable)
 {
 	if(so == INVALID_SOCKET)
@@ -1847,7 +1860,7 @@ int Socket::keepalive(socket_t so, bool enable)
 #if defined(SO_KEEPALIVE) || defined(_MSWINDOWS_)
 	int opt = (enable ? ~0 : 0);
 	return ::setsockopt(so, SOL_SOCKET, SO_KEEPALIVE,
-             (char *)&opt, (socklen_t)sizeof(opt));
+		(char *)&opt, (socklen_t)sizeof(opt));
 #else
 	return -1;
 #endif
