@@ -1,19 +1,19 @@
-// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2010 David Sugar, Tycho Softworks.
 //
-// This file is part of GNU ucommon.
+// This file is part of GNU uCommon C++.
 //
-// GNU ucommon is free software: you can redistribute it and/or modify
+// GNU uCommon C++ is free software: you can redistribute it and/or modify
 // it under the terms of the GNU Lesser General Public License as published 
 // by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// GNU ucommon is distributed in the hope that it will be useful,
+// GNU uCommon C++ is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU Lesser General Public License for more details.
 //
 // You should have received a copy of the GNU Lesser General Public License
-// along with GNU ucommon.  If not, see <http://www.gnu.org/licenses/>.
+// along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
 /**
  * Common socket class and address manipulation.
@@ -646,6 +646,13 @@ public:
 	 */
 	bool waitPending(timeout_t timeout = 0) const;
 
+	/**
+	 * Set nodelay option for tcp socket.
+	 * @return 0 if successful, -1 on error.
+	 */
+	inline int nodelay(void) const
+		{return nodelay(so);};
+
 	/**
 	 * Test for pending input data.  This function can wait up to a specified
 	 * timeout for data to appear.
@@ -1080,6 +1087,13 @@ public:
 	 */
 	static int broadcast(socket_t socket, bool enable);
 
+	/**
+	 * Set tcp nodelay option on socket descriptor.
+	 * @param socket desciptor.
+	 * @return 0 if success, -1 if error.
+	 */
+	static int nodelay(socket_t socket);
+
 	/**
 	 * Set packet priority of socket descriptor.
 	 * @param socket descriptor.
